logging

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 3, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Level = new(slog.LevelVar)

Level is a package-level LevelVar so tests and other code can inspect the current logging level programmatically.

Functions

func Configure

func Configure(k *koanf.Koanf)

Configure sets up the logging subsystem based on koanf configuration.

Types

This section is empty.

Jump to